// Copyright 2010-2021, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
//     * Neither the name of Google Inc. nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#include "gui/base/window_title_modifier.h"

#include <QApplication>
#include <QGuiApplication>
#include <QObject>
#include <QString>
#include <QWidget>

#include "base/version.h"

namespace mozc {
namespace gui {
bool WindowTitleModifier::eventFilter(QObject *obj, QEvent *event) {
  QWidget *w = QApplication::activeWindow();
  if (w == nullptr || obj != w || event->type() != QEvent::WindowActivate) {
    return QObject::eventFilter(obj, event);
  }

  const QString prefix = QLatin1String(" (Dev ");
  const QString& title = w->windowTitle();
  // The window title can be empty, even if it is specified.
  // See: https://doc.qt.io/qt-5/qmessagebox.html#setWindowTitle
  if (!title.isEmpty() && title.indexOf(prefix) == -1) {
    const QString version = prefix + Version::GetMozcVersion().c_str() + ")";
    w->setWindowTitle(title + version);
  }

  return QObject::eventFilter(obj, event);
}

}  // namespace gui
}  // namespace mozc
